function [C,p,mi,z,md]=leadlag(M,F,om,Floss);
%
% function [C,p,mi,z,md]=leadlag(M,F,om,Floss);
%
% Progetto di rete di compensazione integro-derivativa.
%
% INPUT
% M: attenuazione di modulo che si desidera alla pulsazione om (M<1)
% F: recupero di fase (in gradi) che si desidera alla pulsazione om (F<90 gradi)
% om: pulsazione di lavoro della rete (default om=1)
% Floss: (opzionale; default=-10) indica la perdita di fase in gradi introdotta dal
%       termine integrativo della rete in om
%
% OUTPUT
% C: oggetto tf contenente il compensatore integro-derivativo.
% p,mi,z,md: parametri del compensatore:
%       C(s) = Ci(s)*Cd(s)
%               Ci(s) = (s/(mi*p) + 1) / (s/p + 1); Ci(s) = (s/z + 1)/(s/(md*z) +1)
%
% @ G. Calafiore, 2005
%

